@@ -61,9 +61,7 @@ class AbstractBackedDataset(AbstractDataset):
                 d["module"] = pd.Index(module_ids)
         return d
 
-    def get_X(self, dataset_info, keys, root, layer=None):
-        var_ids = dataset_info["var"]
-        X_node = root["X"] if layer is None else root["layers"][layer]
+    def get_X(self, var_ids, keys, node):
         if len(keys) == 1 and isinstance(
             keys[0], slice
         ):  # special case if slice specified for performance
@@ -72,14 +70,12 @@ class AbstractBackedDataset(AbstractDataset):
         else:
             get_item = var_ids.get_indexer_for(keys)
 
-        if self.is_group(X_node):
-            sparse_dataset = SparseDataset(X_node)  # sparse
+        if self.is_group(node):
+            sparse_dataset = SparseDataset(node)  # sparse
             X = sparse_dataset[:, get_item]
         else:  # dense
-            X = self.slice_dense_array(X_node, get_item)
+            X = self.slice_dense_array(node, get_item)
         var = pd.DataFrame(index=keys)
-        if layer is not None:
-            var.index = layer + "-" + var.index.str
         return X, var
 
     def read_dataset(self, filesystem, path, keys=None, dataset=None):
@@ -89,7 +85,6 @@ class AbstractBackedDataset(AbstractDataset):
         basis_keys = keys.pop("basis", [])
         module_keys = keys.pop("module", [])
         # additional keys belong to layers
-        print(keys)
         X = None
         obs = None
         var = None
@@ -99,11 +94,13 @@ class AbstractBackedDataset(AbstractDataset):
         root = self.open_group(filesystem, path)
         layers = {}
         for layer_key in keys.keys():
-            X_layer, var_layer = self.get_X(dataset_info, keys[layer_key], root, layer_key)
+            X_layer, var_layer = self.get_X(
+                dataset_info["var"], keys[layer_key], root["layers"][layer_key]
+            )
             adata_layer = AnnData(X=X_layer, var=var_layer)
             layers[layer_key] = adata_layer
         if len(X_keys) > 0:
-            X, var = self.get_X(dataset_info, X_keys, root)
+            X, var = self.get_X(dataset_info["var"], X_keys, root["X"])
         if len(obs_keys) > 0:
             obs = pd.DataFrame(index=pd.RangeIndex(dataset_info["shape"][0]).astype(str))
             group = root["obs"]
@@ -126,20 +123,10 @@ class AbstractBackedDataset(AbstractDataset):
                         values = pd.Categorical.from_codes(values, categories, ordered=ordered)
                 obs[key] = values
         if len(module_keys) > 0:
-            # stored as dense in module/X, module/var
             module_ids = dataset_info["module"]
             module_X_node = root["uns/module/X"]
-            if len(module_keys) == 1 and isinstance(
-                module_keys[0], slice
-            ):  # special case if slice specified for performance
-                get_item = module_keys[0]
-                module_keys = module_ids[get_item]
-            else:
-                get_item = module_ids.get_indexer_for(module_keys)
-            module_X = self.slice_dense_array(module_X_node, get_item)
-            adata_modules = AnnData(
-                X=module_X, var=pd.DataFrame(index=module_keys), obs=obs
-            )  # obs is shared
+            module_X, module_var = self.get_X(module_ids, module_keys, module_X_node)
+            adata_modules = AnnData(X=module_X, var=module_var, obs=obs)  # obs is shared
         if len(basis_keys) > 0:
             group = root["obsm"]
             for key in basis_keys:
