@@ -247,7 +247,6 @@ def handle_server():
 @cirro_blueprint.route("/category_name", methods=["GET", "PUT"])
 def handle_category_name():
     """CRUD for category name."""
-
     email = get_auth().auth()["email"]
     database_api = get_database()
     if request.method == "GET":
@@ -283,7 +282,6 @@ def handle_category_name():
 @cirro_blueprint.route("/feature_set", methods=["POST", "DELETE"])
 def handle_feature_set():
     """CRUD for a feature set."""
-
     email = get_auth().auth()["email"]
     database_api = get_database()
     # if request.method == 'GET':
@@ -396,9 +394,10 @@ def handle_file():
 
 @cirro_blueprint.route("/user", methods=["GET"])
 def handle_user():
-    email = get_auth().auth()["email"]
+    user = get_auth().auth()
     database_api = get_database()
-    user = database_api.user(email)
+    db_user = database_api.user(user["email"])
+    user.update(db_user)
     return json_response(user)
 
 
@@ -496,6 +495,15 @@ def handle_dataset():
             d["url"] = url
         if request.method == "POST" and url is None:  # new
             return "Must supply dataset URL", 400
+        # TODO trigger prepare job
+        # if request.method == "POST" and not d['url'].lower().endswith('.zarr'):
+        #     d['original_url'] = d['url']
+        #     adata = read_rds(d['url'])
+        #     prepare_data = PrepareData(
+        #         datasets=datasets,
+        #         output=out
+        #     )
+        #     prepare_data.execute()
         dataset_id = database_api.upsert_dataset(email=email, readers=readers, dataset=d)
         return json_response({"id": dataset_id})
     elif request.method == "DELETE":
