@@ -8,12 +8,12 @@ from cirrocumulus.ids_aggregator import IdsAggregator
 from cirrocumulus.unique_aggregator import UniqueAggregator
 
 
-def get_mask(dataset_api, dataset, data_filters):
+def get_mask(dataset_api, dataset, dataset_info, data_filters):
     measures = set()
     dimensions = set()
     basis = set()
     for data_filter in data_filters:
-        _measures, _dimensions, _basis = data_filter_keys(data_filter)
+        _measures, _dimensions, _basis = data_filter_keys(data_filter, dataset_info)
         measures.update(_measures)
         dimensions.update(_dimensions)
         basis.update(_basis)
@@ -34,17 +34,33 @@ def apply_filter(adata, data_filter):
 
 def get_filter_str(data_filter):
     user_filters = data_filter.get("filters", [])
-    # combine_filters = data_filter.get("combine", "and")
+    # example
+    # {
+    #   "filters": [
+    #     {
+    #       "field": "leiden",
+    #       "operation": "in",
+    #       "value": [
+    #         "0"
+    #       ]
+    #     }
+    #   ],
+    #   "combine": "and"
+    # }
+    #    combine_filters = data_filter.get("combine", "and")
     s = []
     for filter_obj in user_filters:
-        field = filter_obj[0]
-        op = filter_obj[1]
-        value = filter_obj[2]
+        field = filter_obj["field"]
+        op = filter_obj["operation"]
+        value = filter_obj["value"]
         if op == "in":
             op = ""
         if not isinstance(field, dict) and not field == "__index":
             if isinstance(value, list):
-                value = "_".join(value)
+                tmp = []
+                for v in value:
+                    tmp.append(str(v))
+                value = "_".join(tmp)
                 s.append(field + "-" + value)
             else:
                 return None
@@ -53,15 +69,26 @@ def get_filter_str(data_filter):
     return "".join(s).replace("/", "-").replace(" ", "-").replace("\\", "-")
 
 
+def _flatten_array(val):
+    if scipy.sparse.issparse(val):
+        val = val.toarray().flatten()
+    if hasattr(val, "sparse"):
+        val = val.sparse.to_dense()
+    if isinstance(val, pd.Series):
+        val = val.values
+    return val
+
+
 def get_filter_expr(adata, data_filter):
     keep_expr = None
     if data_filter is not None:
         user_filters = data_filter.get("filters", [])
         combine_filters = data_filter.get("combine", "and")
         for filter_obj in user_filters:
-            field = filter_obj[0]
-            op = filter_obj[1]
-            value = filter_obj[2]
+            field = filter_obj["field"]
+            op = filter_obj["operation"]
+            value = filter_obj["value"]
+            invert = filter_obj.get("invert", False)
             if isinstance(field, dict):  # selection box
                 # selected_points_basis = get_basis(field['basis'], field.get('nbins'),
                 #                                   field.get('agg'), field.get('ndim', '2'),
@@ -106,27 +133,34 @@ def get_filter_expr(adata, data_filter):
                 )
                 if op == "in":
                     keep = (series.isin(value)).values
-                elif op == ">":
-                    keep = series > value
-                elif op == "=":
-                    keep = series == value
-                elif op == "<":
-                    keep = series < value
-                elif op == "!=":
-                    keep = series != value
-                elif op == ">=":
-                    keep = series >= value
-                elif op == "<=":
-                    keep = series <= value
-                else:
-                    raise ValueError("Unknown filter")
-
-            if scipy.sparse.issparse(keep):
-                keep = keep.toarray().flatten()
-            if hasattr(keep, "sparse"):
-                keep = keep.sparse.to_dense()
-            if isinstance(keep, pd.Series):
-                keep = keep.values
+                else:  # array of operations e.g. >, <
+                    keep = None
+                    for i in range(len(op)):
+                        op_i = op[i]
+                        value_i = value[i]
+                        if op_i == ">":
+                            keep_i = series > value_i
+                        elif op_i == "=":
+                            keep_i = series == value_i
+                        elif op_i == "<":
+                            keep_i = series < value_i
+                        elif op_i == "!=":
+                            keep_i = series != value_i
+                        elif op_i == ">=":
+                            keep_i = series >= value_i
+                        elif op_i == "<=":
+                            keep_i = series <= value_i
+                        else:
+                            raise ValueError(
+                                "Unknown filter, field: {}, operation: {}, value: {}".format(
+                                    field, op, value
+                                )
+                            )
+                        keep_i = _flatten_array(keep_i)
+                        keep = keep_i & keep if keep is not None else keep_i
+            keep = _flatten_array(keep)
+            if invert:
+                keep = ~keep
             if keep_expr is not None:
                 if combine_filters == "and":
                     keep_expr = keep_expr & keep
@@ -162,10 +196,13 @@ def precomputed_embedding(dataset_api, dataset, basis, obs_measures, var_measure
     )
 
 
-def get_var_name_type(key):
+def get_var_name_type(key, default_type="X", dataset_info=None):
     index = key.find("/")
     if index == -1:
-        return key, "X"
+        if dataset_info is not None:
+            key_type = "X" if key in dataset_info["var"] else "obs"
+            return key, key_type
+        return key, default_type
     else:
         key_type = key[0:index]
         name = key[index + 1 :]
@@ -285,12 +322,6 @@ def handle_data(
             else:
                 results["values"][key] = series
 
-        if adata.uns.get(ADATA_MODULE_UNS_KEY) is not None:
-            adata_modules = adata.uns[ADATA_MODULE_UNS_KEY]
-            for i in range(len(adata_modules.var.index)):
-                x = adata_modules.X[:, i]
-                results["values"][adata_modules.var.index[i]] = x
-
         def array_to_json(d, var_index, result):
             is_sparse = scipy.sparse.issparse(d)
             for i in range(len(var_index)):
@@ -302,6 +333,10 @@ def handle_data(
                 else:
                     result[var_index[i]] = x
 
+        if adata.uns.get(ADATA_MODULE_UNS_KEY) is not None:
+            adata_modules = adata.uns[ADATA_MODULE_UNS_KEY]
+            array_to_json(adata_modules.X, adata_modules.var.index, results["values"])
+
         if adata.X is not None:
             array_to_json(adata.X, adata.var.index, results["values"])
         if ADATA_LAYERS_UNS_KEY in adata.uns:
@@ -414,7 +449,7 @@ def get_selected_data(
     return df
 
 
-def data_filter_keys(data_filter):
+def data_filter_keys(data_filter, dataset_info=None):
     var_keys = set()
     obs_keys = set()
     basis_keys = set()
@@ -423,14 +458,16 @@ def data_filter_keys(data_filter):
 
         for i in range(len(user_filters)):
             user_filter = user_filters[i]
-            key = user_filter[0]
+            key = user_filter["field"]
             if isinstance(key, dict):
                 basis_keys.add(key["name"])
             elif key == "__index":
                 continue
             else:
-                name, key_type = get_var_name_type(key)
-                user_filter[0] = name
+                name, key_type = get_var_name_type(
+                    key, default_type="obs", dataset_info=dataset_info
+                )
+                user_filter["field"] = name
                 if key_type == "X":
                     var_keys.add(name)
                 else:
