@@ -12,7 +12,9 @@ CIRRO_MAX_WORKERS = "CIRRO_MAX_WORKERS"
 CIRRO_FOOTER = "CIRRO_FOOTER"
 CIRRO_BRAND = "CIRRO_BRAND"
 CIRRO_UPLOAD = "CIRRO_UPLOAD"
-CIRRO_JOB_RESULTS = "CIRRO_JOB_RESULTS"
+
+CIRRO_COMPRESS = "CIRRO_COMPRESS"
+CIRRO_JOB_RESULTS = "CIRRO_JOB_RESULTS"  # job result storage location
 CIRRO_DATABASE_CLASS = "CIRRO_DATABASE_CLASS"
 CIRRO_DATABASE = "CIRRO_DATABASE"
 CIRRO_DATASET_PROVIDERS = "CIRRO_DATASET_PROVIDERS"
